@@ -7,8 +7,10 @@ import traceback
 from datetime import datetime
 from typing import Callable, List, Dict, Union, Any
 
+from doc_utils import DocUtils
+
 from relevanceai.api.endpoints.client import APIClient
-from relevanceai.api.batch.batch_retrieve import BatchRetrieve
+from relevanceai.api.batch.batch_retrieve import BatchRetrieveClient
 from relevanceai.api.batch.local_logger import PullUpdatePushLocalLogger
 from relevanceai.concurrency import multiprocess, multithread
 from relevanceai.progress_bar import progress_bar
@@ -18,7 +20,7 @@ BYTE_TO_MB = 1024 * 1024
 LIST_SIZE_MULTIPLIER = 3
 
 
-class BatchInsert(BatchRetrieve, APIClient, Chunker):
+class BatchInsertClient(BatchRetrieveClient, APIClient, Chunker, DocUtils):
     def insert_documents(
         self,
         dataset_id: str,
@@ -39,9 +41,9 @@ class BatchInsert(BatchRetrieve, APIClient, Chunker):
         - When inserting or specifying vectors in a document use the suffix (ends with) "_vector_" for the field name. e.g. "product_description_vector_".
         - When inserting or specifying chunks in a document the suffix (ends with) "_chunk_" for the field name. e.g. "products_chunk_".
         - When inserting or specifying chunk vectors in a document's chunks use the suffix (ends with) "_chunkvector_" for the field name. e.g. "products_chunk_.product_description_chunkvector_".
-        
+
         Documentation can be found here: https://ingest-api-dev-aueast.relevance.ai/latest/documentation#operation/InsertEncode
-        
+
         Parameters
         ----------
         dataset_id : string
@@ -150,6 +152,7 @@ class BatchInsert(BatchRetrieve, APIClient, Chunker):
             bulk_fn,
             max_workers,
             retry_chunk_mult,
+            show_progress_bar=show_progress_bar,
             chunksize=chunksize,
         )
 
@@ -168,8 +171,8 @@ class BatchInsert(BatchRetrieve, APIClient, Chunker):
     ):
         """
         Loops through every document in your collection and applies a function (that is specified by you) to the documents.
-        These documents are then uploaded into either an updated collection, or back into the original collection. 
-        
+        These documents are then uploaded into either an updated collection, or back into the original collection.
+
         Parameters
         ----------
         original_collection : string
@@ -196,8 +199,14 @@ class BatchInsert(BatchRetrieve, APIClient, Chunker):
 
         # Check if a logging_collection has been supplied
         if log_file is None:
-            log_file = original_collection + '_' + str(datetime.now().strftime("%d-%m-%Y-%H-%M-%S")) + "_pull_update_push" + ".log"
-        
+            log_file = (
+                original_collection
+                + "_"
+                + str(datetime.now().strftime("%d-%m-%Y-%H-%M-%S"))
+                + "_pull_update_push"
+                + ".log"
+            )
+
         # Instantiate the logger to document the successful IDs
         PULL_UPDATE_PUSH_LOGGER = PullUpdatePushLocalLogger(log_file)
 
@@ -206,9 +215,7 @@ class BatchInsert(BatchRetrieve, APIClient, Chunker):
 
         # Trust the process
         # Get document lengths to calculate iterations
-        original_length = self.datasets.documents._get_number_of_documents(
-            original_collection, filters
-        )
+        original_length = self.get_number_of_documents(original_collection, filters)
 
         # get the remaining number in case things break
         remaining_length = original_length - PULL_UPDATE_PUSH_LOGGER.count_ids_in_fn()
@@ -234,7 +241,7 @@ class BatchInsert(BatchRetrieve, APIClient, Chunker):
                 original_collection,
                 filters=retrieve_filters,
                 page_size=retrieve_chunk_size,
-                select_fields=select_fields
+                select_fields=select_fields,
             )
 
             documents = orig_json["documents"]
@@ -273,8 +280,8 @@ class BatchInsert(BatchRetrieve, APIClient, Chunker):
                 f"Chunk of {retrieve_chunk_size} original documents updated and uploaded with {len(chunk_failed)} failed documents!"
             )
 
-        self.logger.success(f"Pull, Update, Push is complete!") 
-        
+        self.logger.success(f"Pull, Update, Push is complete!")
+
         # if PULL_UPDATE_PUSH_LOGGER.count_ids_in_fn() == original_length:
         #     os.remove(log_file)
         return {
@@ -300,7 +307,7 @@ class BatchInsert(BatchRetrieve, APIClient, Chunker):
         """
         Loops through every document in your collection and applies a function (that is specified by you) to the documents.
         These documents are then uploaded into either an updated collection, or back into the original collection.
-        
+
         Parameters
         ----------
         original_collection : string
@@ -324,17 +331,18 @@ class BatchInsert(BatchRetrieve, APIClient, Chunker):
         """
         # Check if a logging_collection has been supplied
         if logging_collection is None:
-            logging_collection = original_collection + '_' + str(datetime.now().strftime("%d-%m-%Y-%H-%M-%S")) + "_pull_update_push"
+            logging_collection = (
+                original_collection
+                + "_"
+                + str(datetime.now().strftime("%d-%m-%Y-%H-%M-%S"))
+                + "_pull_update_push"
+            )
 
         # Check collections and create completed list if needed
         collection_list = self.datasets.list()
         if logging_collection not in collection_list["datasets"]:
             self.logger.info("Creating a logging collection for you.")
-            self.logger.info(
-                self.datasets.create(
-                    logging_collection
-                )
-            )
+            self.logger.info(self.datasets.create(logging_collection))
 
         # Track failed documents
         failed_documents: List[Dict] = []
@@ -343,12 +351,8 @@ class BatchInsert(BatchRetrieve, APIClient, Chunker):
         for _ in range(number_of_retrieve_retries):
 
             # Get document lengths to calculate iterations
-            original_length = self.datasets.documents._get_number_of_documents(
-                original_collection, filters
-            )
-            completed_length = self.datasets.documents._get_number_of_documents(
-                logging_collection
-            )
+            original_length = self.get_number_of_documents(original_collection, filters)
+            completed_length = self.get_number_of_documents(logging_collection)
             remaining_length = original_length - completed_length
             iterations_required = math.ceil(remaining_length / retrieve_chunk_size)
 
@@ -369,9 +373,7 @@ class BatchInsert(BatchRetrieve, APIClient, Chunker):
             ):
 
                 # Get completed documents
-                log_json = self.get_all_documents(
-                    logging_collection
-                )
+                log_json = self.get_all_documents(logging_collection)
                 completed_documents_list = [i["_id"] for i in log_json]
 
                 # Get incomplete documents from raw collection
@@ -388,7 +390,7 @@ class BatchInsert(BatchRetrieve, APIClient, Chunker):
                     original_collection,
                     filters=retrieve_filters,
                     page_size=retrieve_chunk_size,
-                    select_fields=select_fields
+                    select_fields=select_fields,
                 )
 
                 documents = orig_json["documents"]
@@ -472,7 +474,7 @@ class BatchInsert(BatchRetrieve, APIClient, Chunker):
         ]
         return self.insert_documents(dataset_id, docs, *args, **kwargs)
 
-    def delete_pull_update_push_logs(self, dataset_id = False):
+    def delete_pull_update_push_logs(self, dataset_id=False):
 
         collection_list = self.datasets.list()["datasets"]
 
@@ -484,11 +486,7 @@ class BatchInsert(BatchRetrieve, APIClient, Chunker):
             ]
 
         else:
-            log_collections = [
-                i
-                for i in collection_list
-                if ("pull_update_push" in i)
-            ]
+            log_collections = [i for i in collection_list if ("pull_update_push" in i)]
 
         [self.datasets.delete(i, confirm=False) for i in log_collections]
         return
@@ -506,7 +504,7 @@ class BatchInsert(BatchRetrieve, APIClient, Chunker):
 
         # Get one document to test the size
         if len(docs) == 0:
-            self.logger.warn("No document is detected")
+            self.logger.warning("No document is detected")
             return {
                 "inserted": 0,
                 "failed_documents": [],
@@ -518,8 +516,14 @@ class BatchInsert(BatchRetrieve, APIClient, Chunker):
         doc_mb = sys.getsizeof(test_doc) * LIST_SIZE_MULTIPLIER / BYTE_TO_MB
         if chunksize == 0:
             target_chunk_mb = int(self.config.get_option("upload.target_chunk_mb"))
-            chunksize = int(target_chunk_mb / doc_mb) + 1 if int(target_chunk_mb/ doc_mb) + 1 < len(docs) else len(docs)
-    
+            max_chunk_size = int(self.config.get_option("upload.max_chunk_size"))
+            chunksize = (
+                int(target_chunk_mb / doc_mb) + 1
+                if int(target_chunk_mb / doc_mb) + 1 < len(docs)
+                else len(docs)
+            )
+            chunksize = max(chunksize, max_chunk_size)
+
         # Initialise number of inserted documents
         inserted: List[str] = []
 
@@ -606,3 +610,79 @@ class BatchInsert(BatchRetrieve, APIClient, Chunker):
             "failed_documents_detailed": failed_ids_detailed,
         }
         return output
+
+    def rename_fields(
+        self,
+        dataset_id: str,
+        field_mappings: dict,
+        retrieve_chunk_size: int = 100,
+        max_workers: int = 8,
+        show_progress_bar: bool = True,
+    ):
+        """
+        Loops through every document in your collection and renames specified fields by deleting the old one and
+        creating a new field using the provided mapping
+        These documents are then uploaded into either an updated collection, or back into the original collection.
+
+        Example:
+        rename_fields(dataset_id,field_mappings = {'a.b.d':'a.b.c'})  => doc['a']['b']['d'] => doc['a']['b']['c']
+        rename_fields(dataset_id,field_mappings = {'a.b':'a.c'})  => doc['a']['b'] => doc['a']['c']
+
+        Parameters
+        ----------
+        dataset_id : string
+            The dataset_id of the collection where your original documents are
+        field_mappings : dict
+            A dictionary in the form f {old_field_name1 : new_field_name1, ...}
+        retrieve_chunk_size: int
+            The number of documents that are received from the original collection with each loop iteration.
+        retrieve_chunk_size_failure_retry_multiplier: int
+            If fails, retry on each chunk
+        max_workers: int
+            The number of processors you want to parallelize with
+        show_progress_bar: bool
+            Shows a progress bar if True
+        """
+        self.logger.warning(
+            "Currently this function is in beta and may change in the future."
+        )
+
+        skip = set()
+        for old_f, new_f in field_mappings.items():
+            if len(old_f.split(".")) != len(new_f.split(".")):
+                skip.add(old_f)
+                self.logger.warning(f"{old_f} does not match {new_f}.")
+
+        for k in skip:
+            del field_mappings[k]
+
+        def rename_dict_fields(d, field_mappings={}, track=""):
+            modified_dict = {}
+            for k, v in sorted(d.items(), key=lambda x: x[0]):
+                if track != "" and track[-1] != ".":
+                    track += "."
+                if track + k not in field_mappings.keys():
+                    kk = k
+                else:
+                    kk = field_mappings[track + k].split(".")[-1]
+
+                if isinstance(v, dict):
+                    if k not in modified_dict:
+                        modified_dict[kk] = {}
+                    modified_dict[kk] = rename_dict_fields(
+                        v, field_mappings, track + kk
+                    )
+                else:
+                    modified_dict[kk] = v
+            return modified_dict
+
+        sample_docs = self.datasets.documents.list(dataset_id)
+
+        def update_function(sample_docs):
+            for i, d in enumerate(sample_docs):
+                sample_docs[i] = rename_dict_fields(
+                    d, field_mappings=field_mappings, track=""
+                )
+            return sample_docs
+
+        self.pull_update_push(dataset_id, update_function, retrieve_chunk_size=200)
