@@ -1,7 +1,8 @@
-from relevanceai.base import Base
+from relevanceai.base import _Base
 from typing import List
 
-class Search(Base):
+
+class SearchClient(_Base):
     def __init__(self, project, api_key):
         self.project = project
         self.api_key = api_key
@@ -28,12 +29,13 @@ class Search(Base):
         include_count=True,
         asc=False,
         keep_search_history=False,
-        hundred_scale = False,
-        search_history_id = None
+        hundred_scale=False,
+        search_history_id=None,
+        query: str = None,
     ):
-        """ 
+        """
         Allows you to leverage vector similarity search to create a semantic search engine. Powerful features of VecDB vector search:
-        
+
         1. Multivector search that allows you to search with multiple vectors and give each vector a different weight. e.g. Search with a product image vector and text description vector to find the most similar products by what it looks like and what its described to do. You can also give weightings of each vector field towards the search, e.g. image_vector_ weights 100%, whilst description_vector_ 50% \n
             An example of a simple multivector query:
 
@@ -41,7 +43,7 @@ class Search(Base):
             >>>     {"vector": [0.12, 0.23, 0.34], "fields": ["name_vector_"], "alias":"text"},
             >>>     {"vector": [0.45, 0.56, 0.67], "fields": ["image_vector_"], "alias":"image"},
             >>> ]
-            
+
             An example of a weighted multivector query:
 
             >>> [
@@ -74,7 +76,7 @@ class Search(Base):
         4. Personalization with positive and negative document ids.
 
             - For more information about the positive and negative document ids to personalize check out services.recommend.vector
-        
+
         For more even more advanced configuration and customisation of vector search, reach out to us at dev@relevance.ai and learn about our new advanced_vector_search.
 
         Parameters
@@ -119,6 +121,8 @@ class Search(Base):
             Whether to scale up the metric by 100
         search_history_id: string
             Search history ID, only used for storing search histories.
+        query: string
+            What to store as the query name in the dashboard
         """
         return self.make_http_request(
             "/services/search/vector",
@@ -143,8 +147,9 @@ class Search(Base):
                 "asc": asc,
                 "keep_search_history": keep_search_history,
                 "hundred_scale": hundred_scale,
-                "search_history_id": search_history_id
-            }
+                "search_history_id": search_history_id,
+                "query": query,
+            },
         )
 
     def hybrid(
@@ -167,10 +172,10 @@ class Search(Base):
         include_count=True,
         asc=False,
         keep_search_history=False,
-        hundred_scale = False,
-        search_history_id = None
+        hundred_scale=False,
+        search_history_id=None,
     ):
-        """ 
+        """
         Combine the best of both traditional keyword faceted search with semantic vector search to create the best search possible. \n
 
         For information on how to use vector search check out services.search.vector. \n
@@ -255,7 +260,8 @@ class Search(Base):
                 "edit_distance": edit_distance,
                 "ignore_spaces": ignore_spaces,
                 "traditional_weight": traditional_weight,
-            }
+                "query": text,
+            },
         )
 
     def semantic(
@@ -275,9 +281,9 @@ class Search(Base):
         include_count=True,
         asc=False,
         keep_search_history=False,
-        hundred_scale = False
+        hundred_scale=False,
     ):
-        """ 
+        """
         A more automated hybrid search with a few extra things that automatically adjusts some of the key parameters for more automated and good out of the box results. \n
 
         For information on how to configure semantic search check out services.search.hybrid.
@@ -345,7 +351,8 @@ class Search(Base):
                 "asc": asc,
                 "keep_search_history": keep_search_history,
                 "hundred_scale": hundred_scale,
-            }
+                "query": text,
+            },
         )
 
     def diversity(
@@ -374,11 +381,12 @@ class Search(Base):
         search_history_id: str = None,
         n_init: int = 5,
         n_iter: int = 10,
-        return_as_clusters: bool = False
+        return_as_clusters: bool = False,
+        query: str = None,
     ):
-        """ 
+        """
         This will first perform an advanced search and then cluster the top X (page_size) search results. Results are returned as such: Once you have the clusters:
-        
+
         >>> Cluster 0: [A, B, C]
         >>> Cluster 1: [D, E]
         >>> Cluster 2: [F, G]
@@ -448,6 +456,8 @@ class Search(Base):
             Number of iterations in each run
         return_as_clusters: bool
             If True, return as clusters as opposed to results list
+        query: string
+            What to store as the query name in the dashboard
         """
         return self.make_http_request(
             "/services/search/diversity",
@@ -478,7 +488,8 @@ class Search(Base):
                 "n_init": n_init,
                 "n_iter": n_iter,
                 "return_as_clusters": return_as_clusters,
-            }
+                "query": query,
+            },
         )
 
     def traditional(
@@ -495,9 +506,9 @@ class Search(Base):
         include_count: bool = True,
         asc: bool = False,
         keep_search_history: bool = False,
-        search_history_id: str = None
+        search_history_id: str = None,
     ):
-        """ 
+        """
         Traditional Faceted Keyword Search with edit distance/fuzzy matching. \n
 
         For information on how to apply facets/filters check out datasets.documents.get_where. \n
@@ -552,7 +563,8 @@ class Search(Base):
                 "asc": asc,
                 "keep_search_history": keep_search_history,
                 "search_history_id": search_history_id,
-            }
+                "query": "text",
+            },
         )
 
     def chunk(
@@ -575,12 +587,13 @@ class Search(Base):
         include_count: bool = True,
         asc: bool = False,
         keep_search_history: bool = False,
-        hundred_scale: bool = False
+        hundred_scale: bool = False,
+        query: str = None,
     ):
 
-        """ 
+        """
         Chunks are data that has been divided into different units. e.g. A paragraph is made of many sentence chunks, a sentence is made of many word chunks, an image frame in a video. By searching through chunks you can pinpoint more specifically where a match is occuring. When creating a chunk in your document use the suffix "chunk" and "chunkvector". An example of a document with chunks:
-        
+
         >>> {
         >>>     "_id" : "123",
         >>>     "title" : "Lorem Ipsum Article",
@@ -592,7 +605,7 @@ class Search(Base):
         >>>         {"sentence_id" : 2, "sentence_chunkvector_" : [0.7, 0.8, 0.9], "sentence" : "It has survived not only five centuries, but also the leap into electronic typesetting, remaining essentially unchanged."},
         >>>     ]
         >>> }
-        
+
         For combining chunk search with other search check out services.search.advanced_chunk.
 
         Parameters
@@ -635,6 +648,8 @@ class Search(Base):
             Whether to store the history into VecDB. This will increase the storage costs over time.
         hundred_scale: bool
             Whether to scale up the metric by 100
+        query: string
+            What to store as the query name in the dashboard
         """
 
         return self.make_http_request(
@@ -659,8 +674,9 @@ class Search(Base):
                 "include_count": include_count,
                 "asc": asc,
                 "keep_search_history": keep_search_history,
-                "hundred_scale": hundred_scale
-            }
+                "hundred_scale": hundred_scale,
+                "query": query,
+            },
         )
 
     def multistep_chunk(
@@ -686,10 +702,11 @@ class Search(Base):
         keep_search_history: bool = False,
         hundred_scale: bool = False,
         first_step_page: int = 1,
-        first_step_page_size: int = 20
+        first_step_page_size: int = 20,
+        query: str = None,
     ):
 
-        """ 
+        """
         Multistep chunk search involves a vector search followed by chunk search, used to accelerate chunk searches or to identify context before delving into relevant chunks. e.g. Search against the paragraph vector first then sentence chunkvector after. \n
 
         For more information about chunk search check out services.search.chunk. \n
@@ -742,6 +759,8 @@ class Search(Base):
             Page of the results
         first_step_page_size: int
             Size of each page of results
+        query: string
+            What to store as the query name in the dashboard
         """
         return self.make_http_request(
             "/services/search/multistep_chunk",
@@ -769,7 +788,8 @@ class Search(Base):
                 "first_step_multivector_query": first_step_multivector_query,
                 "first_step_page": first_step_page,
                 "first_step_page_size": first_step_page_size,
-            }
+                "query": query,
+            },
         )
 
     def advanced_chunk(
@@ -779,19 +799,20 @@ class Search(Base):
         min_score: int = None,
         page_size: int = 20,
         include_vector: bool = False,
-        select_fields: list = []
+        select_fields: list = [],
+        query: str = None,
     ):
-        """ 
+        """
         A more advanced chunk search to be able to combine vector search and chunk search in many different ways. \n
         Example 1 (Hybrid chunk search):
         >>> chunk_query = {
         >>>     "chunk" : "some.test",
         >>>     "queries" : [
-        >>>         {"vector" : vec1, "fields": {"some.test.some_chunkvector_":1}, 
-        >>>         "traditional_query" : {"text":"python", "fields" : ["some.test.test_words"], "traditional_weight": 0.3}, 
+        >>>         {"vector" : vec1, "fields": {"some.test.some_chunkvector_":1},
+        >>>         "traditional_query" : {"text":"python", "fields" : ["some.test.test_words"], "traditional_weight": 0.3},
         >>>         "metric" : "cosine"},
-        >>>         {"vector" : vec, "fields": ["some.test.tt.some_other_chunkvector_"], 
-        >>>         "traditional_query" : {"text":"jumble", "fields" : ["some.test.test_words"], "traditional_weight": 0.3}, 
+        >>>         {"vector" : vec, "fields": ["some.test.tt.some_other_chunkvector_"],
+        >>>         "traditional_query" : {"text":"jumble", "fields" : ["some.test.test_words"], "traditional_weight": 0.3},
         >>>         "metric" : "cosine"},
         >>>     ]
         >>> }
@@ -819,9 +840,9 @@ class Search(Base):
         >>>             "chunk": "some.test",
         >>>         },
         >>>         {
-        >>>             "vector" : vec, 
+        >>>             "vector" : vec,
         >>>             "fields": {
-        >>>                 ".some_vector_" : 0.1}, 
+        >>>                 ".some_vector_" : 0.1},
         >>>                 "metric" : "cosine"
         >>>                 },
         >>>         ]
@@ -841,6 +862,8 @@ class Search(Base):
             Include vectors in the search results
         select_fields: list
             Fields to include in the search results, empty array/list means all fields.
+        query: string
+            What to store as the query name in the dashboard
         """
         return self.make_http_request(
             "/services/search/advanced_chunk",
@@ -852,7 +875,8 @@ class Search(Base):
                 "min_score": min_score,
                 "include_vector": include_vector,
                 "select_fields": select_fields,
-            }
+                "query": query,
+            },
         )
 
     def advanced_multistep_chunk(
@@ -873,9 +897,10 @@ class Search(Base):
         min_score: int = 0,
         page_size: int = 20,
         include_vector: bool = False,
-        select_fields: list = []
+        select_fields: list = [],
+        query: str = None,
     ):
-        """ 
+        """
         Performs a vector hybrid search and then an advanced chunk search. Chunk Search allows one to search through chunks inside a document. The major difference between chunk search and normal search in Vector AI is that it relies on the chunkvector field. Chunk Vector Search. Search with a multiple chunkvectors for the most similar documents. Chunk search also supports filtering to only search through filtered results and facets to get the overview of products available when a minimum score is set. \n
 
         Example 1 (Hybrid chunk search):
@@ -883,11 +908,11 @@ class Search(Base):
         >>> chunk_query = {
         >>>     "chunk" : "some.test",
         >>>     "queries" : [
-        >>>         {"vector" : vec1, "fields": {"some.test.some_chunkvector_":1}, 
-        >>>         "traditional_query" : {"text":"python", "fields" : ["some.test.test_words"], "traditional_weight": 0.3}, 
+        >>>         {"vector" : vec1, "fields": {"some.test.some_chunkvector_":1},
+        >>>         "traditional_query" : {"text":"python", "fields" : ["some.test.test_words"], "traditional_weight": 0.3},
         >>>         "metric" : "cosine"},
-        >>>         {"vector" : vec, "fields": ["some.test.tt.some_other_chunkvector_"], 
-        >>>         "traditional_query" : {"text":"jumble", "fields" : ["some.test.test_words"], "traditional_weight": 0.3}, 
+        >>>         {"vector" : vec, "fields": ["some.test.tt.some_other_chunkvector_"],
+        >>>         "traditional_query" : {"text":"jumble", "fields" : ["some.test.test_words"], "traditional_weight": 0.3},
         >>>         "metric" : "cosine"},
         >>>     ]
         >>> }
@@ -915,9 +940,9 @@ class Search(Base):
         >>>             "chunk": "some.test",
         >>>         },
         >>>         {
-        >>>             "vector" : vec, 
+        >>>             "vector" : vec,
         >>>             "fields": {
-        >>>                 ".some_vector_" : 0.1}, 
+        >>>                 ".some_vector_" : 0.1},
         >>>                 "metric" : "cosine"
         >>>                 },
         >>>         ]
@@ -959,7 +984,8 @@ class Search(Base):
             Include vectors in the search results
         select_fields: list
             Fields to include in the search results, empty array/list means all fields.
-
+        query: string
+            What to store as the query name in the dashboard
         """
         return self.make_http_request(
             "/services/search/advanced_multistep_chunk",
@@ -982,61 +1008,72 @@ class Search(Base):
                 "page_size": page_size,
                 "include_vector": include_vector,
                 "select_fields": select_fields,
-            }
+                "query": query,
+            },
         )
 
-    def _init_experiment_helper(self, categories = ['chunk', 'vector', 'diversity', 'traditional']):
+    def _init_experiment_helper(
+        self, categories=["chunk", "vector", "diversity", "traditional"]
+    ):
         self.categories = categories
-        self.traditional_search_doc = "https://docs.relevance.ai/docs/better-text-search-with-hybrid"
+        self.traditional_search_doc = (
+            "https://docs.relevance.ai/docs/better-text-search-with-hybrid"
+        )
         self.vector_search_doc = "https://docs.relevance.ai/docs/pure-word-matching-pure-vector-search-or-combination-of-both"
         self.diversity_search_doc = "https://docs.relevance.ai/docs/better-text-search-diversified-search-results"
         self.hybrid_search_doc = "https://docs.relevance.ai/docs/pure-word-matching-pure-vector-search-or-combination-of-both-1"
         self.semantic_search_doc = "https://docs.relevance.ai/docs/pure-word-matching-pure-vector-search-or-combination-of-both-2"
-        self.chunk_search_doc =  "https://docs.relevance.ai/docs/better-text-search-chunk-search"
+        self.chunk_search_doc = (
+            "https://docs.relevance.ai/docs/better-text-search-chunk-search"
+        )
         self.multistep_chunk_doc = "https://docs.relevance.ai/docs/fine-grained-search-search-on-chunks-of-text-data"
         self.advanced_chunk_doc = "https://docs.relevance.ai/docs/fine-grained-search-search-on-chunks-of-text-data-1"
         self.advanced_multistep_chunk_doc = "https://docs.relevance.ai/docs/fine-grained-search-search-on-chunks-of-text-data-2"
 
         self.initiative_messages = "What else to experiment with :)\n"
         self.category_initiative_messages = {
-            'chunk': "if you are searching on large pieces of text, you could chunk your data and try\n",
-            'vector': "if you are looking for strong conceptual relations and not just word matching, you could try\n",
-            'diversity': "if you are looking for strong conceptual relations as well as diverse results, you could try\n",
-            'traditional': "if you are looking for specific text such as id, names, etc., you could try\n",
+            "chunk": "if you are searching on large pieces of text, you could chunk your data and try\n",
+            "vector": "if you are looking for strong conceptual relations and not just word matching, you could try\n",
+            "diversity": "if you are looking for strong conceptual relations as well as diverse results, you could try\n",
+            "traditional": "if you are looking for specific text such as id, names, etc., you could try\n",
         }
 
     def make_suggestion(self):
         if hasattr(self, "_last_used_endpoint"):
-            self.last_search = self._last_used_endpoint.split('/')[-1]
+            self.last_search = self._last_used_endpoint.split("/")[-1]
         else:
             self.last_search = None
         suggestion = self.initiative_messages
-        if 'traditional' in self.categories and self.last_search != 'traditional':
-            suggestion += self.category_initiative_messages['traditional']
+        if "traditional" in self.categories and self.last_search != "traditional":
+            suggestion += self.category_initiative_messages["traditional"]
             suggestion += f"   * traditional search ({self.traditional_search_doc})\n"
 
-        if 'vector' in self.categories:
-            suggestion += self.category_initiative_messages['vector']
+        if "vector" in self.categories:
+            suggestion += self.category_initiative_messages["vector"]
             if self.last_search != "vector":
-                 suggestion += f"   * vector search ({self.vector_search_doc})\n"
+                suggestion += f"   * vector search ({self.vector_search_doc})\n"
             if self.last_search != "hybrid":
-                 suggestion += f"   * hybrid search ({self.hybrid_search_doc})\n"
+                suggestion += f"   * hybrid search ({self.hybrid_search_doc})\n"
             if self.last_search != "semantic":
-                 suggestion += f"   * semantic search ({self.semantic_search_doc})\n"
+                suggestion += f"   * semantic search ({self.semantic_search_doc})\n"
 
-        if 'diversity' in self.categories and self.last_search != 'diversity':
-            suggestion += self.category_initiative_messages['diversity']
+        if "diversity" in self.categories and self.last_search != "diversity":
+            suggestion += self.category_initiative_messages["diversity"]
             suggestion += f"   * diversity search ({self.diversity_search_doc})\n"
 
-        if 'chunk' in self.categories:
-          suggestion += self.category_initiative_messages['chunk']
-          if self.last_search != "chunk":
-              suggestion += f"   * chunk search ({self.chunk_search_doc})\n"
-          if self.last_search != "multistep_chunk":
-              suggestion += f"   * multistep_chunk search ({self.multistep_chunk_doc})\n"
-          if self.last_search != "advanced_chunk":
-              suggestion += f"   * advanced_chunk search ({self.advanced_chunk_doc})\n"
-          if self.last_search != "advanced_multistep_chunk":
-              suggestion += f"   * advanced_multistep_chunk search ({self.advanced_multistep_chunk_doc})\n"
+        if "chunk" in self.categories:
+            suggestion += self.category_initiative_messages["chunk"]
+            if self.last_search != "chunk":
+                suggestion += f"   * chunk search ({self.chunk_search_doc})\n"
+            if self.last_search != "multistep_chunk":
+                suggestion += (
+                    f"   * multistep_chunk search ({self.multistep_chunk_doc})\n"
+                )
+            if self.last_search != "advanced_chunk":
+                suggestion += (
+                    f"   * advanced_chunk search ({self.advanced_chunk_doc})\n"
+                )
+            if self.last_search != "advanced_multistep_chunk":
+                suggestion += f"   * advanced_multistep_chunk search ({self.advanced_multistep_chunk_doc})\n"
 
-        return {"search":suggestion}
+        return {"search": suggestion}
