@@ -10,8 +10,8 @@ def str2bool(v):
     return v.lower() in ("yes", "true", "t", "1")
 
 
-class Base(Transport, LoguruLogger):
-    """Base class for all relevanceai utilities"""
+class _Base(Transport, LoguruLogger):
+    """Base class for all relevanceai client utilities"""
 
     def __init__(self, project: str, api_key: str):
         self.project = project
